@@ -36,7 +36,7 @@
 #include <llvm/Support/raw_ostream.h>
 
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 
 
 OSLCompiler::OSLCompiler(ErrorHandler* errhandler)
@@ -85,11 +85,6 @@ OSLCompiler::output_filename() const
 namespace pvt {  // OSL::pvt
 
 
-static ustring op_for("for");
-static ustring op_while("while");
-static ustring op_dowhile("dowhile");
-
-
 
 OSLCompilerImpl::OSLCompilerImpl(ErrorHandler* errhandler)
     : m_errhandler(errhandler ? errhandler : &ErrorHandler::default_handler())
@@ -595,7 +590,7 @@ OSLCompilerImpl::write_dependency_file(string_view filename)
                          : OIIO::Filesystem::fopen(m_deps_filename, "w"));
     if (depfile) {
         OSL::print(depfile, "{}: {}", target, filename);
-        for (const auto& dep : m_file_dependencies) {
+        for (ustring dep : m_file_dependencies) {
             if (OIIO::Strutil::ends_with(dep, "stdosl.h")
                 && !m_generate_system_deps)
                 continue;  // skip system headers if so instructed
@@ -603,6 +598,16 @@ OSLCompilerImpl::write_dependency_file(string_view filename)
                 continue;  // skip pseudo files
             if (dep == filename)
                 continue;  // skip this file, since we already put it first
+#if defined(_WIN32) && defined(OSL_CI)
+            // Special behavior for CI on Windows: remove the directory paths
+            // for the dependencies, or else it won't match the reference
+            // output.
+            using OIIO::Strutil::replace;
+            std::string cwd = replace(OIIO::Filesystem::current_path() + "/",
+                                      "/", "\\", true);
+            auto d          = replace(dep, "\\\\", "\\", true);
+            dep             = ustring(replace(d, cwd, ""));
+#endif
             OSL::print(depfile, " \\\n  {}", dep);
         }
         OSL::print(depfile, "\n");
@@ -632,20 +637,15 @@ struct GlobalTable {
 void
 OSLCompilerImpl::initialize_globals()
 {
-    static GlobalTable globals[]
-        = { { "P", TypeDesc::TypePoint, false },
-            { "I", TypeDesc::TypeVector, false },
-            { "N", TypeDesc::TypeNormal, false },
-            { "Ng", TypeDesc::TypeNormal },
-            { "u", TypeDesc::TypeFloat },
-            { "v", TypeDesc::TypeFloat },
-            { "dPdu", TypeDesc::TypeVector },
-            { "dPdv", TypeDesc::TypeVector },
-            { "Ps", TypeDesc::TypePoint },
-            { "Ci", TypeSpec(TypeDesc::TypeColor, true), false },
-            { "time", TypeDesc::TypeFloat },
-            { "dtime", TypeDesc::TypeFloat },
-            { "dPdtime", TypeDesc::TypeVector } };
+    static GlobalTable globals[] = {
+        { "P", TypePoint, false },  { "I", TypeVector, false },
+        { "N", TypeNormal, false }, { "Ng", TypeNormal },
+        { "u", TypeFloat },         { "v", TypeFloat },
+        { "dPdu", TypeVector },     { "dPdv", TypeVector },
+        { "Ps", TypePoint },        { "Ci", TypeSpec(TypeColor, true), false },
+        { "time", TypeFloat },      { "dtime", TypeFloat },
+        { "dPdtime", TypeVector }
+    };
 
     for (auto& g : globals) {
         Symbol* s = new Symbol(ustring(g.name), g.type, SymTypeGlobal);
@@ -706,7 +706,7 @@ OSLCompilerImpl::write_oso_const_value(const ConstantSymbol* sym) const
     else if (elemtype == TypeDesc::FLOAT)
         for (int i = 0; i < nelements; ++i)
             osofmt("{:.9g}{}", sym->floatval(i), nelements > 1 ? " " : "");
-    else if (equivalent(elemtype, TypeDesc::TypeVector))
+    else if (equivalent(elemtype, TypeVector))
         for (int i = 0; i < nelements; ++i) {
             Vec3 v = sym->get_vec3(i);
             osofmt("{:.9g} {:.9g} {:.9g}{}", v.x, v.y, v.z,
@@ -774,7 +774,7 @@ OSLCompilerImpl::write_oso_symbol(const Symbol* sym)
             if (i > 0)
                 fieldlist += ",";
             fieldlist += structspec->field(i).name.string();
-            signature += code_from_type(structspec->field(i).type);
+            signature += structspec->field(i).type.code_from_type();
         }
         osofmt(
             "{}%struct{{\"{}\"}} %structfields{{{}}} %structfieldtypes{{\"{}\"}} %structnfields{{{}}}",
@@ -1073,19 +1073,6 @@ OSLCompilerImpl::pop_nesting(bool isloop)
 }
 
 
-
-const char*
-OSLCompilerImpl::type_c_str(const TypeSpec& type) const
-{
-    if (type.is_structure())
-        return ustring::fmtformat("struct {}", type.structspec()->name())
-            .c_str();
-    else
-        return type.c_str();
-}
-
-
-
 void
 OSLCompilerImpl::struct_field_pair(Symbol* sym1, Symbol* sym2, int fieldnum,
                                    Symbol*& field1, Symbol*& field2)
@@ -1167,92 +1154,6 @@ OSLCompilerImpl::check_for_illegal_writes()
 
 
 
-/// Called after code is generated, this function loops over all the ops
-/// and figures out the lifetimes of all variables, based on whether the
-/// args in each op are read or written.
-void
-OSLCompilerImpl::track_variable_lifetimes(const OpcodeVec& code,
-                                          const SymbolPtrVec& opargs,
-                                          const SymbolPtrVec& allsyms,
-                                          std::vector<int>* bblockids)
-{
-    // Clear the lifetimes for all symbols
-    for (auto&& s : allsyms)
-        s->clear_rw();
-
-    // Keep track of the nested loops we're inside. We track them by pairs
-    // of begin/end instruction numbers for that loop body, including
-    // conditional evaluation (skip the initialization). Note that the end
-    // is inclusive. We use this vector of ranges as a stack.
-    typedef std::pair<int, int> intpair;
-    std::vector<intpair> loop_bounds;
-
-    // For each op, mark its arguments as being used at that op
-    int opnum = 0;
-    for (auto&& op : code) {
-        if (op.opname() == op_for || op.opname() == op_while
-            || op.opname() == op_dowhile) {
-            // If this is a loop op, we need to mark its control variable
-            // (the only arg) as used for the duration of the loop!
-            OSL_DASSERT(op.nargs() == 1);  // loops should have just one arg
-            SymbolPtr s  = opargs[op.firstarg()];
-            int loopcond = op.jump(0);  // after initialization, before test
-            int loopend  = op.farthest_jump() - 1;  // inclusive end
-            s->mark_rw(opnum + 1, true, true);
-            s->mark_rw(loopend, true, true);
-            // Also push the loop bounds for this loop
-            loop_bounds.push_back(std::make_pair(loopcond, loopend));
-        }
-
-        // Some work to do for each argument to the op...
-        for (int a = 0; a < op.nargs(); ++a) {
-            SymbolPtr s = opargs[op.firstarg() + a];
-            OSL_DASSERT(s->dealias() == s);  // Make sure it's de-aliased
-
-            // Mark that it's read and/or written for this op
-            bool readhere    = op.argread(a);
-            bool writtenhere = op.argwrite(a);
-            s->mark_rw(opnum, readhere, writtenhere);
-
-            // Adjust lifetimes of symbols whose values need to be preserved
-            // between loop iterations.
-            for (auto oprange : loop_bounds) {
-                int loopcond = oprange.first;
-                int loopend  = oprange.second;
-                OSL_DASSERT(s->firstuse() <= loopend);
-                // Special case: a temp or local, even if written inside a
-                // loop, if it's entire lifetime is within one basic block
-                // and it's strictly written before being read, then its
-                // lifetime is truly local and doesn't need to be expanded
-                // for the duration of the loop.
-                if (bblockids
-                    && (s->symtype() == SymTypeLocal
-                        || s->symtype() == SymTypeTemp)
-                    && (*bblockids)[s->firstuse()] == (*bblockids)[s->lastuse()]
-                    && s->lastwrite() < s->firstread()) {
-                    continue;
-                }
-                // Syms written before or inside the loop, and referenced
-                // inside or after the loop, need to preserve their value
-                // for the duration of the loop. We know it's referenced
-                // inside the loop because we're here examining it!
-                if (s->firstwrite() <= loopend) {
-                    s->mark_rw(loopcond, readhere, writtenhere);
-                    s->mark_rw(loopend, readhere, writtenhere);
-                }
-            }
-        }
-
-        ++opnum;  // Advance to the next op index
-
-        // Pop any loop bounds for loops we've just exited
-        while (!loop_bounds.empty() && loop_bounds.back().second < opnum)
-            loop_bounds.pop_back();
-    }
-}
-
-
-
 // This has O(n^2) memory usage, so only for debugging
 //#define DEBUG_SYMBOL_DEPENDENCIES
 
@@ -1502,4 +1403,4 @@ OSLCompilerImpl::syms_used_in_op_range(OpcodeVec::const_iterator opbegin,
 
 };  // namespace pvt
 
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
