@@ -18,7 +18,7 @@
 #include <llvm/Pass.h>
 #include <llvm/Support/Casting.h>
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 
 namespace pvt {
 
@@ -60,7 +60,6 @@ public:
         llvm::Type* llvm_type_bool  = llvm::Type::getInt1Ty(context);
         llvm::Type* llvm_type_int32 = llvm::Type::getInt32Ty(context);
 
-#if OSL_LLVM_VERSION >= 110
         m_llvm_mask_type = llvm::FixedVectorType::get(llvm_type_bool, WidthT);
         // NOTE:  OSL doesn't have any 16 bit data types, so 32bit version
         // of the mask promotion will always be correct here.  Should 16 bit
@@ -71,19 +70,13 @@ public:
         // livein.
         m_native_mask_type = llvm::FixedVectorType::get(llvm_type_int32,
                                                         WidthT);
-#    if OSL_LLVM_VERSION >= 112
+#if OSL_LLVM_VERSION >= 112
         m_wide_zero_initializer = llvm::ConstantDataVector::getSplat(
             WidthT, llvm::ConstantInt::get(context, llvm::APInt(32, 0)));
-#    else
+#else
         m_wide_zero_initializer = llvm::ConstantVector::getSplat(
             llvm::ElementCount(WidthT, false),
             llvm::ConstantInt::get(context, llvm::APInt(32, 0)));
-#    endif
-#else
-        m_llvm_mask_type   = llvm::VectorType::get(llvm_type_bool, WidthT);
-        m_native_mask_type = llvm::VectorType::get(llvm_type_int32, WidthT);
-        m_wide_zero_initializer = llvm::ConstantVector::getSplat(
-            WidthT, llvm::ConstantInt::get(context, llvm::APInt(32, 0)));
 #endif
     }
 
@@ -436,6 +429,8 @@ public:
 // including this file will need its own static members defined. LLVM will
 // assign IDs when they get registered, so this initialization value is not
 // important.
+template<> char LegacyPreventBitMasksFromBeingLiveinsToBasicBlocks<4>::ID = 0;
+
 template<> char LegacyPreventBitMasksFromBeingLiveinsToBasicBlocks<8>::ID = 0;
 
 template<> char LegacyPreventBitMasksFromBeingLiveinsToBasicBlocks<16>::ID = 0;
@@ -443,4 +438,4 @@ template<> char LegacyPreventBitMasksFromBeingLiveinsToBasicBlocks<16>::ID = 0;
 }  // end of anonymous namespace
 
 }  // namespace pvt
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
